/* vi:set ts=8 sts=0 sw=8:
 * $Id: recent.h,v 1.6 1999/12/10 18:07:44 kahn Exp kahn $
 *
 * Copyright (C) 1998 Andy C. Kahn
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef __RECENT_H__
#define __RECENT_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#include "main.h"
#ifdef USE_RECENT
#include "win.h"

extern void	recent_list_add(win_t *w, char *fname);
extern void	recent_list_init(win_t *w);
extern void	recent_list_write(win_t *w);
extern void	recent_list_free(win_t *w);

#else

#define recent_list_add(w, f)
#define recent_list_init(w)
#define recent_list_write(w)
#define recent_list_free(w)

#endif	/* USE_RECENT */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif	/* __RECENT_H__ */
